In the camp of the Black Rider by Capwell Wyckoff | Project Gutenberg
Description: Free kindle book and epub digitized and proofread by volunteers.
Keywords: ebook, ebooks, free ebooks, free books, book, books, audio books

# In the camp of the Black Rider by Capwell Wyckoff

## Read now or download (free!)

| Choose how to read this book | Url | Size |  |  |
--- | --- | --- | --- | --- | --- | ---
| Read online (web) | https://www.gutenberg.org/ebooks/75217.html.images | 342 kB |  |  |
| EPUB3 (E-readers incl. Send-to-Kindle) | https://www.gutenberg.org/ebooks/75217.epub3.images | 501 kB |  |  |
| EPUB (older E-readers) | https://www.gutenberg.org/ebooks/75217.epub.images | 498 kB |  |  |
| EPUB (no images, older E-readers) | https://www.gutenberg.org/ebooks/75217.epub.noimages | 376 kB |  |  |
| Kindle | https://www.gutenberg.org/ebooks/75217.kf8.images | 1.3 MB |  |  |
| older Kindles | https://www.gutenberg.org/ebooks/75217.kindle.images | 1.2 MB |  |  |
| Plain Text UTF-8 | https://www.gutenberg.org/ebooks/75217.txt.utf-8 | 303 kB |  |  |
| Download HTML (zip) | https://www.gutenberg.org/cache/epub/75217/pg75217-h.zip | 919 kB |  |  |
| There may be more files related to this item.

## Similar Books

Readers also downloaded…

## About this eBook

Author | Wyckoff, Capwell, 1903-1953
Title | In the camp of the Black Rider
Original Publication | United States: A. L. Burt Company, 1931.
Credits | Bob Taylor, Tim Lindell and the Online Distributed Proofreading Team at https://www.pgdp.net (This book was produced from images made available by the HathiTrust Digital Library.)
Language | English
Category | Text
EBook-No. | 75217
Release Date | Jan 26, 2025
Copyright Status | Public domain in the USA.
Downloads | 118 downloads in the last 30 days.
Project Gutenberg eBooks are always free!